@@ -4,12 +4,8 @@
 
 #include "iccomp.h"
 
-unsigned rm_jmp_zero(codelen, list, listlen)
-    register unsigned
-        codelen,
-        listlen;
-    unsigned
-        *list;
+size_t rm_jmp_zero(register size_t codelen, unsigned *list, 
+                   register size_t listlen)
 {
     return
     (
